DatumAnnotation class
Constructors
- DatumAnnotation({required double startPosition, required double endPosition, required RangeAnnotationAxisType axisType})
- DatumAnnotation.from(DatumAnnotation other, [double? startPosition, double? endPosition])
-
factory
Properties
- axisType → RangeAnnotationAxisType
-
final
- endPosition → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startPosition → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited